package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicCanteenSuggestion;
import com.bonus.canteen.core.basic.service.IBasicCanteenSuggestionService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 投诉建议 Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "投诉建议 接口")
@RestController
@RequestMapping("/basic_canteen_suggestion")
public class BasicCanteenSuggestionController extends BaseController {
    @Autowired
    private IBasicCanteenSuggestionService basicCanteenSuggestionService;

    /**
     * 查询投诉建议 列表
     */
    @ApiOperation(value = "查询投诉建议 列表")
    //@RequiresPermissions("basic:suggestion:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicCanteenSuggestion basicCanteenSuggestion) {
        startPage();
        List<BasicCanteenSuggestion> list = basicCanteenSuggestionService.selectBasicCanteenSuggestionList(basicCanteenSuggestion);
        return getDataTable(list);
    }

    /**
     * 导出投诉建议 列表
     */
    @ApiOperation(value = "导出投诉建议 列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:suggestion:export")
    @SysLog(title = "投诉建议 ", businessType = OperaType.EXPORT, logType = 1,module = "食堂管理->导出投诉建议 ")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicCanteenSuggestion basicCanteenSuggestion) {
        List<BasicCanteenSuggestion> list = basicCanteenSuggestionService.selectBasicCanteenSuggestionList(basicCanteenSuggestion);
        ExcelUtil<BasicCanteenSuggestion> util = new ExcelUtil<BasicCanteenSuggestion>(BasicCanteenSuggestion.class);
        util.exportExcel(response, list, "投诉建议 数据");
    }

    /**
     * 获取投诉建议 详细信息
     */
    @ApiOperation(value = "获取投诉建议 详细信息")
    //@RequiresPermissions("basic:suggestion:query")
    @GetMapping(value = "/{suggestionId}")
    public AjaxResult getInfo(@PathVariable("suggestionId") Long suggestionId) {
        return success(basicCanteenSuggestionService.selectBasicCanteenSuggestionBySuggestionId(suggestionId));
    }

    /**
     * 新增投诉建议 
     */
    @ApiOperation(value = "新增投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:suggestion:add")
    @SysLog(title = "投诉建议 ", businessType = OperaType.INSERT, logType = 1,module = "食堂管理->新增投诉建议 ")
    @PostMapping
    public AjaxResult add(@RequestBody BasicCanteenSuggestion basicCanteenSuggestion) {
        try {
            return toAjax(basicCanteenSuggestionService.insertBasicCanteenSuggestion(basicCanteenSuggestion));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改投诉建议 
     */
    @ApiOperation(value = "修改投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:suggestion:edit")
    @SysLog(title = "投诉建议 ", businessType = OperaType.UPDATE, logType = 1,module = "食堂管理->修改投诉建议 ")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicCanteenSuggestion basicCanteenSuggestion) {
        try {
            return toAjax(basicCanteenSuggestionService.updateBasicCanteenSuggestion(basicCanteenSuggestion));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    @ApiOperation(value = "回复投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:suggestion:edit")
    @SysLog(title = "回复投诉建议 ", businessType = OperaType.UPDATE, logType = 1,module = "食堂管理->回复投诉建议 ")
    @PostMapping("/reply")
    public AjaxResult reply(@RequestBody BasicCanteenSuggestion basicCanteenSuggestion) {
        try {
            basicCanteenSuggestion.setReplyState(1L);
            return toAjax(basicCanteenSuggestionService.updateBasicCanteenSuggestion(basicCanteenSuggestion));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除投诉建议 
     */
    @ApiOperation(value = "删除投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:suggestion:remove")
    @SysLog(title = "投诉建议 ", businessType = OperaType.DELETE, logType = 1,module = "食堂管理->删除投诉建议 ")
	@PostMapping("/del/{suggestionIds}")
    public AjaxResult remove(@PathVariable Long[] suggestionIds) {
        return toAjax(basicCanteenSuggestionService.deleteBasicCanteenSuggestionBySuggestionIds(suggestionIds));
    }
}
